==> cams_ncp_client-0.0.3-py3-none-any.whl: cams_ncp_client/client.py <==
from typing import Optional

import requests

from cams_ncp_client.cams_file import CamsFileClient
from cams_ncp_client.forecast import ForecastClient
from cams_ncp_client.model import ModelClient
from cams_ncp_client.observation import ObservationClient
from cams_ncp_client.quantity import QuantityClient
from cams_ncp_client.station import StationClient
from vito.sas.air.utils.date_utils import iso_utc_to_datetime


# from cams_ncp_api.client.utils.date_utils import iso_utc_to_datetime


class CamsNcpApiClient:


    """
    Client for interacting with the CAMS NCP API.

    Attributes:
        base_url (str): The base URL for the API.
        session (requests.Session): Session for making HTTP requests.

    Usage:
    >>> client = CamsNcpApiClient(base_url="http://localhost:5050")
    >>> quantities = client.quantity.get_quantities_df()
    >>> stations = client.station.find_stations(limit=10, quantity="PM10")
    >>> observations = client.observation.find_observations(station_name="42N016", start_time=iso_utc_to_datetime("2023-01-01T00:00:00Z"))
    """
    def __init__(self,
            base_url: str,
            session: Optional[requests.Session] = None
    ):
        self.base_url = base_url.rstrip('/')
        self.session = session if session is not None else requests.Session()
        self._station = None
        self._quantity = None
        self._observation = None
        self._forecast = None
        self._model = None
        self._cams_file = None

    @property
    def station(self) -> StationClient:
        if self._station is None:
            self._station = StationClient(self.base_url, self.session)
        return self._station

    @property
    def quantity(self) -> QuantityClient:
        if self._quantity is None:
            self._quantity = QuantityClient(self.base_url, self.session)
        return self._quantity

    @property
    def observation(self) -> ObservationClient:
        if self._observation is None:
            self._observation = ObservationClient(self.base_url, self.session)
        return self._observation

    @property
    def forecast(self) -> ForecastClient:
        if self._forecast is None:
            self._forecast = ForecastClient(self.base_url, self.session)
        return self._forecast

    @property
    def model(self) -> ModelClient:
        if self._model is None:
            self._model = ModelClient(self.base_url, self.session)
        return self._model

    @property
    def cams_file(self) -> CamsFileClient:
        if self._cams_file is None:
            self._cams_file = CamsFileClient(self.base_url, self.session)
        return self._cams_file

==> cams_ncp_client-0.1.0-py3-none-any.whl: cams_ncp_client/client.py <==
from typing import Optional

import requests

from cams_ncp_client.cams_file import CamsFileClient
from cams_ncp_client.forecast import ForecastClient
from cams_ncp_client.model import ModelClient
from cams_ncp_client.observation import ObservationClient
from cams_ncp_client.quantity import QuantityClient
from cams_ncp_client.station import StationClient

class CamsNcpApiClient:
    """
    Client for interacting with the CAMS NCP API.

    Attributes:
       base_url (str): The base URL for the API.
       session (requests.Session): Session for making HTTP requests.

    Example usage:

    >>>  from vito.sas.air.utils.date_utils import iso_utc_to_datetime
    >>>  client = CamsNcpApiClient(base_url="http://localhost:8080")
    >>>  quantities = client.quantity.get_quantities_df()
    >>>  stations = client.station.find_stations(limit=10, quantity="PM10")
    >>>  observations = client.observation.find_observations(station_name="42N016", start_time=iso_utc_to_datetime("2023-01-01T00:00:00Z"))
    """

    def __init__(self,
            base_url: str,
            session: Optional[requests.Session] = None
    ):
        self.base_url = base_url.rstrip('/')
        self.session = session if session is not None else requests.Session()
        self._station = None
        self._quantity = None
        self._observation = None
        self._forecast = None
        self._model = None
        self._cams_file = None

    @property
    def station(self) -> StationClient:
        if self._station is None:
            self._station = StationClient(self.base_url, self.session)
        return self._station

    @property
    def quantity(self) -> QuantityClient:
        if self._quantity is None:
            self._quantity = QuantityClient(self.base_url, self.session)
        return self._quantity

    @property
    def observation(self) -> ObservationClient:
        if self._observation is None:
            self._observation = ObservationClient(self.base_url, self.session)
        return self._observation

    @property
    def forecast(self) -> ForecastClient:
        if self._forecast is None:
            self._forecast = ForecastClient(self.base_url, self.session)
        return self._forecast

    @property
    def model(self) -> ModelClient:
        if self._model is None:
            self._model = ModelClient(self.base_url, self.session)
        return self._model

    @property
    def cams_file(self) -> CamsFileClient:
        if self._cams_file is None:
            self._cams_file = CamsFileClient(self.base_url, self.session)
        return self._cams_file
